# Author: S.Chekanov (ANL) 
# This is an realistic job option file for NtupleMaker
# http://atlaswww.hep.anl.gov/asc/WebSVN/listing.php?repname=NtupleMaker


lumi=0.0
print "Integrated lumi=",lumi 


from AthenaCommon.Constants import *
from AthenaCommon.AppMgr import theApp
from AthenaCommon.AppMgr import ServiceMgr
import AthenaPoolCnvSvc.ReadAthenaPool

#################### this part for ArCond
include("InputCollection.py")
ServiceMgr.EventSelector.InputCollections = dataCollection
################################################



############# the rest is any job options you like #####################
## input
from AthenaCommon.AthenaCommonFlags  import athenaCommonFlags
athenaCommonFlags.FilesInput.set_Value_and_Lock(ServiceMgr.EventSelector.InputCollections)
# or single line?
# from AthenaCommon.AthenaCommonFlags import jobproperties as jp
# jp.AthenaCommonFlags.FilesInput = fileList


############### MinBias ############################
DetDescrVersion = 'ATLAS-GEO-08-00-02'

from AthenaCommon.GlobalFlags import globalflags
from AthenaCommon.BeamFlags import jobproperties
globalflags.DetGeo = 'atlas'
globalflags.InputFormat = 'pool'
globalflags.DetDescrVersion = DetDescrVersion
globalflags.DataSource  = 'data' # 'geant4'# 
jobproperties.Beam.beamType = 'collisions' # 'cosmics' # 'singlebeam' # 
if globalflags.DataSource != 'geant4':
   DoTruth = False
else:
   globalflags.ConditionsTag = 'OFLCOND-DR-BS900-ANom-03'

globalflags.print_JobProperties()


if len(globalflags.ConditionsTag())!=0:
   from IOVDbSvc.CondDB import conddb
   conddb.setGlobalTag(globalflags.ConditionsTag())

# --- default is zero luminosity
import AthenaCommon.SystemOfUnits as Units
jobproperties.Beam.numberOfCollisions = 2.0 # default in RecExCommon for 900 GeV
jobproperties.Beam.energy             = 450.*Units.GeV
jobproperties.Beam.beamType           = 'collisions'

from AthenaCommon.BFieldFlags import jobproperties
jobproperties.BField.solenoidOn=True


## Load Tracking Tools
#  include( "RecoOptions.py" )

#--------------------------------------------------------------
# Configure Trigger Reading
#--------------------------------------------------------------
### help from joerg
from TriggerJobOpts.TriggerConfigGetter import TriggerConfigGetter
cfg = TriggerConfigGetter("ReadPool")

## Load algorithm to TopSequence
from AthenaCommon.AlgSequence import AlgSequence
topSequence = AlgSequence()

if globalflags.DataSource == 'data':
    include("InDetBeamSpotService/BeamCondSvc.py")
    conddb.addOverride("/Indet/Beampos", 'IndetBeampos-r988-Collision_2009_02-v0')
### Pixel disable module tag
from IOVDbSvc.CondDB import conddb
conddb.addOverride('/PIXEL/PixMapOverlay', 'PixMapOverlay-Coll09-75-00')


from AthenaCommon.GlobalFlags import GlobalFlags
GlobalFlags.DetGeo.set_atlas()
GlobalFlags.DataSource.set_data()
### from Deepak
from AthenaCommon.GlobalFlags  import globalflags
globalflags.DetDescrVersion=DetDescrVersion
# needed for the detector geometry 
include( "RecExCond/AllDet_detDescr.py" )
include ('TrkDetDescrSvc/AtlasTrackingGeometrySvc.py')
include( "ParticleBuilderOptions/AOD_PoolCnv_jobOptions.py" ) 
include( "ParticleBuilderOptions/McAOD_PoolCnv_jobOptions.py" )
include ( "EventAthenaPool/EventAthenaPool_joboptions.py" )
include('TrkDetDescrSvc/AtlasTrackingGeometrySvc.py')
include( "TrackIsolationTools/TrackIsolationTool_jobOptions.py" )



#-------------------------------------------------------------------------
# Algorithms
#-------------------------------------------------------------------------
from AthenaCommon.AlgSequence import AlgSequence
theJob = AlgSequence()


from  NtupleMaker.NtupleMakerConf  import MainNtupleMaker
theJob += MainNtupleMaker(OutputLevel = INFO)


# Number of Events to process
# theApp.EvtMax = 1000 


# fill edditional trees wth detailed information on egamma object
# (isolation, leakage etc)
MainNtupleMaker.SavePIDVariables = True  

# fill ntuple or not?
MainNtupleMaker.SaveNtuple = True


# get containers  
MainNtupleMaker.PhotonContainer = "PhotonAODCollection"
MainNtupleMaker.ElectronContainer = "ElectronAODCollection"
MainNtupleMaker.MCParticleContainer = "SpclMC"

#  cuts for prompt photons (in GeV)
MainNtupleMaker.PhotonEtCut  = 3.0
MainNtupleMaker.PhotonEtaCut = 2.4 


#  cuts for electron (in GeV)
MainNtupleMaker.ElectronEtCut  = 3.0
MainNtupleMaker.ElectronEtaCut = 2.4 



# Muon Parameters (in GeV) 
# Collections can be: MuidMuonCollection or StacoMuonCollection 
MainNtupleMaker.MuonContainer = "StacoMuonCollection"
MainNtupleMaker.MuonEtCut  = 3.0  
MainNtupleMaker.MuonEtaCut = 2.4

## Tau collections 
MainNtupleMaker.TauContainer = "TauRecContainer"
MainNtupleMaker.TauEtCut  = 3.0
MainNtupleMaker.TauEtaCut = 2.4

# reject event if the cone R=0.3 around photon has sum of PT above this cut
MainNtupleMaker.PhotonMinTrackP = 5.0 


# set it to true for ATLFAST simulation 
MainNtupleMaker.UseAtlfast = FALSE

# tracks
MainNtupleMaker.TrackParticleContainer= "TrackParticleCandidate"
# MainNtupleMaker.TrackParticleContainer= "AtlfastTrackParticles"

# trigger items need to be given with the prefix L1_, L2_ or EF_
# MainNtupleMaker.TriggerTaken=["EF_g25_L32"]
MainNtupleMaker.TriggerTaken=["L1_MBTS_1_1"]

# do you want to cut event based on the trigger above?
MainNtupleMaker.UseTriggerCut = True

#  jets
MainNtupleMaker.JetRecoContainer = "AntiKt4H1TopoJets"
MainNtupleMaker.JetEtCut  = 3.0
MainNtupleMaker.JetEtaCut = 2.5

# There is only one Atlfast ParticleJet Collection in the AOD,
# corresponding to a Cone4 jet algorithm
# MainNtupleMaker.JetRecoContainer = "AtlfastParticleJetContainer"


# take only leading jet or gamma or not?
# set to TRUE  if only leading jet or gamma is considered
MainNtupleMaker.OnlyLeadingObject = TRUE

# when all jets and photons above cuts are taken.   
# MainNtupleMaker.OnlyLeadingObject = FALSE

# take only exotic events into ntuple
MainNtupleMaker.UseEventCutForNtuple=FALSE


# to remove gamma from the jet list,
# use matching parameter in phi and eta
MainNtupleMaker.DeltaRMatchGammaJet=0.2


## true jets
#  Cone7TruthParticleJets
#  Kt4TruthParticleJets
#  Kt6TruthParticleJets
MainNtupleMaker.JetTrueContainer = "AntiKt4TruthJets"


# set this true if you want to run over photons
# which do not originate from the quarks lines
MainNtupleMaker.TakeBackgroundOnly=False


# miss PT
# MainNtupleMaker.MissingETKey="AtlfastMissingEt"
MainNtupleMaker.MissingETKey="MET_Final"

# 1) tightness==0
#   -- take all photons for reconstructed  level
#   -- Truth: defined by IsoConeTrue cone size (0.4) and minFraction IsoConeMinPtTrue (0.9) 
# 2) tightness==1
#   -- take  cone40 isolated photons for reconstructed. Use loose definition 
#   -- Truth: defined by IsoConeTrue cone size (0.4) and minFraction IsoConeMinPtTrue (0.9) 
# 3) tightness==2
#   -- take  cone40 isolated photons for reconstructed. Use tight definition 
#   -- Truth: defined by IsoConeTrue cone size (0.4) and minFraction IsoConeMinPtTrue (0.9) 
# 4) tightness==3
#   -- take  a cluster isolation with arbitrary cone size. Use tight definition 
#         -> defined by IsoConeTrue cone size (0.4) and minFraction IsoConeMinPtTrue (0.9)
#   -- Truth: defined by IsoConeTrue cone size (0.4) and minFraction IsoConeMinPtTrue (0.9) 
# take all photons
MainNtupleMaker.PhotonTightness=0

# for resolution studies only! 
# max distance in phi and eta between true and reconstructed
MainNtupleMaker.DeltaRMatchCutGamma  =0.2 
MainNtupleMaker.DeltaRMatchCutJet    =0.2


# isolation for cone for true and reconstructed level
# take only true photons with PT/Etot >0.9 in the cone = 1
# if IsoConeTrue is less than 0, the isolation will be done
# with the cone 0.4 using calorimeter cells using econe40 variable.
MainNtupleMaker.IsoConeTrue = 0.4
MainNtupleMaker.IsoConeMinPtTrue= 0.9

# min missing ET for objects used to calculate gamma-object invariant mass
MainNtupleMaker.MissETmin = 10. # in GeV 

# output
# Set output level threshold (2=DEBUG, 3=INFO, 4=WARNING, 5=ERROR, 6=FATAL )
MainNtupleMaker.OutputLevel = 4


# do not change this! This is an automatic variable!
MainNtupleMaker.Luminosity = lumi

# set to true for no any calculations
MainNtupleMaker.RunFastNoCalculations = False
 
# moment calculations
MainNtupleMaker.DoMomentCalculation = True;


#########################################
# trigger configuration
from TriggerJobOpts.TriggerConfigGetter import TriggerConfigGetter
cfg = TriggerConfigGetter('ReadPool')
# TDT
from AthenaCommon.AppMgr import ToolSvc
from TrigDecisionTool.TrigDecisionToolConf import Trig__TrigDecisionTool
tdt = Trig__TrigDecisionTool("TrigDecisionTool")
ToolSvc += tdt

# might be needed for TriggerConfigGetter...
from RecExConfig.RecFlags  import rec
rec.readRDO=False
rec.readAOD=True
rec.doWriteAOD=False
rec.doWriteESD=False
########## end trigger

## collect statistics
photons = ["L1_2EM13", "L2_2g10_mu6", "EF_2g10","EF_g10_loose"]
electrons = ["EF_e10_loose", "EF_e15_medium", "EF_e20_loose", "EF_e25i_loose"]
jets= ["EF_2j10","EF_2j20","EF_2j40","EF_j40","EF_j140","EF_j200","EF_3j80", "EF_j40", "EF_jE120", "EF_FJ70", "EF_FJ35","EF_3j40"]

# collect statistics for these triggers
MainNtupleMaker.StatTriggerChains = photons + electrons+jets;


AthenaEventLoopMgr = Service("AthenaEventLoopMgr")
AthenaEventLoopMgr.OutputLevel = WARNING


# output file
from GaudiSvc.GaudiSvcConf import THistSvc
ServiceMgr += THistSvc()
ServiceMgr.THistSvc.Output = ["AANT DATAFILE='Analysis.root' OPT='RECREATE'"]


# Set output level threshold (2=DEBUG, 3=INFO, 4=WARNING, 5=ERROR, 6=FATAL )
MessageSvc = Service( "MessageSvc" )
MessageSvc.OutputLevel = 5
